@@ -24,9 +24,9 @@
 
 __author__ = "Dilshod Temirkhodjaev <tdilshod@gmail.com>"
 __license__ = "MIT"
-__version__ = "0.8"
+__version__ = "0.8.1"
 
-import csv, datetime, zipfile, string, sys, os, re, signal
+import csv, datetime, zipfile, sys, os, re, signal
 import xml.parsers.expat
 from xml.dom import minidom
 
@@ -130,9 +130,6 @@ CONTENT_TYPES = {
 DEFAULT_APP_PATH = "/xl"
 DEFAULT_WORKBOOK_PATH = DEFAULT_APP_PATH + "/workbook.xml"
 
-def eprint(*args, **kwargs):
-    print(*args, file=sys.stderr, **kwargs)
-
 class XlsxException(Exception):
     pass
 
@@ -173,6 +170,7 @@ class Xlsx2csv:
        include_sheet_pattern - only include sheets named matching given pattern
        exclude_sheet_pattern - exclude sheets named matching given pattern
        exclude_hidden_sheets - exclude hidden sheets
+       skip_hidden_rows - skip hidden rows
     """
 
     def __init__(self, xlsxfile, **options):
@@ -195,6 +193,7 @@ class Xlsx2csv:
         options.setdefault("ignore_formats", [''])
         options.setdefault("lineterminator", "\n")
         options.setdefault("outputencoding", "utf-8")
+        options.setdefault("skip_hidden_rows", True)
 
         self.options = options
         try:
@@ -346,6 +345,7 @@ class Xlsx2csv:
                 sheet.set_merge_cells(self.options['merge_cells'])
                 sheet.set_scifloat(self.options['scifloat'])
                 sheet.set_ignore_formats(self.options['ignore_formats'])
+                sheet.set_skip_hidden_rows(self.options['skip_hidden_rows'])
                 if self.options['escape_strings'] and sheet.filedata:
                     sheet.filedata = re.sub(r"(<v>[^<>]+)&#10;([^<>]+</v>)", r"\1\\n\2",
                                             re.sub(r"(<v>[^<>]+)&#9;([^<>]+</v>)", r"\1\\t\2",
@@ -654,6 +654,7 @@ class Sheet:
         self.hyperlinks = {}
         self.mergeCells = {}
         self.ignore_formats = []
+        self.skip_hidden_rows = False
 
         self.colIndex = 0
         self.colNum = ""
@@ -681,6 +682,9 @@ class Sheet:
     def set_ignore_formats(self, ignore_formats):
         self.ignore_formats = ignore_formats
 
+    def set_skip_hidden_rows(self, skip_hidden_rows):
+        self.skip_hidden_rows = skip_hidden_rows
+
     def set_merge_cells(self, mergecells):
         if not mergecells:
             return
@@ -814,15 +818,15 @@ class Sheet:
 
                 if format_str in FORMATS:
                     format_type = FORMATS[format_str]
-                elif re.match("^\d+(\.\d+)?$", self.data) and re.match(".*[hsmdyY]", format_str) and not re.match(
+                elif re.match(r"^\d+(\.\d+)?$", self.data) and re.match(".*[hsmdyY]", format_str) and not re.match(
                         '.*\[.*[dmhys].*\]', format_str):
                     # it must be date format
                     if float(self.data) < 1:
                         format_type = "time"
                     else:
                         format_type = "date"
-                elif re.match("^-?\d+(.\d+)?$", self.data) or (
-                            self.scifloat and re.match("^-?\d+(.\d+)?([eE]-?\d+)?$", self.data)):
+                elif re.match(r"^-?\d+(.\d+)?$", self.data) or (
+                            self.scifloat and re.match(r"^-?\d+(.\d+)?([eE]-?\d+)?$", self.data)):
                     format_type = "float"
                 if format_type == 'date' and self.dateformat == 'float':
                     format_type = "float"
@@ -890,7 +894,7 @@ class Sheet:
                     (name == 'v' or name == 'is') or (has_namespace and (name.endswith(':v') or name.endswith(':is')))):
             self.in_cell_value = True
             self.collected_string = ""
-        elif self.in_sheet and (name == 'row' or (has_namespace and name.endswith(':row'))) and ('r' in attrs) and not ('hidden' in attrs and attrs['hidden'] == '1'):
+        elif self.in_sheet and (name == 'row' or (has_namespace and name.endswith(':row'))) and ('r' in attrs) and not (self.skip_hidden_rows and 'hidden' in attrs and attrs['hidden'] == '1'):
             self.rowNum = attrs['r']
             self.in_row = True
             self.colIndex = 0
@@ -908,9 +912,9 @@ class Sheet:
         elif name == 'dimension':
             rng = attrs.get("ref").split(":")
             if len(rng) > 1:
-                start = re.match("^([A-Z]+)(\d+)$", rng[0])
+                start = re.match(r"^([A-Z]+)(\d+)$", rng[0])
                 if (start):
-                    end = re.match("^([A-Z]+)(\d+)$", rng[1])
+                    end = re.match(r"^([A-Z]+)(\d+)$", rng[1])
                     startCol = start.group(1)
                     endCol = end.group(1)
                     self.columns_count = 0
@@ -995,8 +999,8 @@ class Sheet:
         if len(rng) == 1:
             yield rangeStr
         else:
-            start = re.match("^([A-Z]+)(\d+)$", rng[0])
-            end = re.match("^([A-Z]+)(\d+)$", rng[1])
+            start = re.match(r"^([A-Z]+)(\d+)$", rng[0])
+            end = re.match(r"^([A-Z]+)(\d+)$", rng[1])
             if not start or not end:
                 return
             startCol = start.group(1)
@@ -1107,6 +1111,8 @@ def main():
                         help="quoting - fields quoting in csv, 'none' 'minimal' 'nonnumeric' or 'all' (default: minimal)")
     parser.add_argument("-s", "--sheet", dest="sheetid", default=1, type=inttype,
                         help="sheet number to convert")
+    parser.add_argument("--include-hidden-rows", dest="include_hidden_rows", default=False, action="store_true",
+                        help="include hidden rows")
 
     if argparser:
         options = parser.parse_args()
@@ -1181,7 +1187,8 @@ def main():
         'merge_cells': options.merge_cells,
         'outputencoding': options.outputencoding,
         'lineterminator': options.lineterminator,
-        'ignore_formats': options.ignore_formats
+        'ignore_formats': options.ignore_formats,
+        'skip_hidden_rows': not options.include_hidden_rows
     }
     sheetid = options.sheetid
     if options.all:
